diff --git a/office-alexander-logistics-app/src/main/webapp/pages/workitems/parts/alexander/spaceref.xhtml b/office-alexander-logistics-app/src/main/webapp/pages/workitems/parts/alexander/spaceref.xhtml
index 4e2f50a..aa734c1 100644
--- a/office-alexander-logistics-app/src/main/webapp/pages/workitems/parts/alexander/spaceref.xhtml
+++ b/office-alexander-logistics-app/src/main/webapp/pages/workitems/parts/alexander/spaceref.xhtml
@@ -17,7 +17,7 @@
itemValue="#{space.item['$UniqueID']}">
-
+
diff --git a/office-alexander-logistics-app/src/main/webapp/js/imixs-office.workitem.custom.js b/office-alexander-logistics-app/src/main/webapp/js/imixs-office.workitem.custom.js
index 86bdcd6..c99bfa9 100644
--- a/office-alexander-logistics-app/src/main/webapp/js/imixs-office.workitem.custom.js
+++ b/office-alexander-logistics-app/src/main/webapp/js/imixs-office.workitem.custom.js
@@ -6,10 +6,15 @@
*
*/
$(document).ready(function() {
- /*
- * Hier berechnen wir anhand der Eingabe im Feld alexander-logistic-date-days
- * ein neues Datum auf basis des Rechnungsdatum (date_invoice)
- */
+ initFaelligkeit();
+
+});
+
+/*
+* Hier setzen wir einen Event handler und berechnen anhand der Eingabe im Feld alexander-logistic-date-days
+* ein neues Datum auf basis des Rechnungsdatum (date_invoice)
+*/
+function initFaelligkeit(ajax_event) {
$(".alexander-logistic-date-days").change(function(e) {
var days = $(this).val();
if (days=='') {
@@ -56,10 +61,7 @@ $(document).ready(function() {
$(this).val('');
});
-
-});
-
-
+}
// erweitere datums eingabe
// TTMM
@@ -102,5 +104,4 @@ function validateBuchungsDatum(item) {
// update field....
$(mhd).val(text);
-
}